# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/insurance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/insurance/v1beta1/insurance.proto',
  package='injective.insurance.v1beta1',
  syntax='proto3',
  serialized_options=b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+injective/insurance/v1beta1/insurance.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x9b\x01\n\x06Params\x12\x8a\x01\n)default_redemption_notice_period_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB<\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x30yaml:\"default_redemption_notice_period_duration\":\x04\xe8\xa0\x1f\x01\"\xec\x03\n\rInsuranceFund\x12\x15\n\rdeposit_denom\x18\x01 \x01(\t\x12\"\n\x1ainsurance_pool_token_denom\x18\x02 \x01(\t\x12z\n!redemption_notice_period_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB4\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f(yaml:\"redemption_notice_period_duration\"\x12?\n\x07\x62\x61lance\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x43\n\x0btotal_share\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x11\n\tmarket_id\x18\x06 \x01(\t\x12\x15\n\rmarket_ticker\x18\x07 \x01(\t\x12\x13\n\x0boracle_base\x18\x08 \x01(\t\x12\x14\n\x0coracle_quote\x18\t \x01(\t\x12\x39\n\x0boracle_type\x18\n \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\x0b \x01(\x03\"\xed\x01\n\x12RedemptionSchedule\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08marketId\x18\x02 \x01(\t\x12\x10\n\x08redeemer\x18\x03 \x01(\t\x12k\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB,\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f yaml:\"claimable_redemption_time\"\x12:\n\x11redemption_amount\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"T\n\x18\x45ventInsuranceFundUpdate\x12\x38\n\x04\x66und\x18\x01 \x01(\x0b\x32*.injective.insurance.v1beta1.InsuranceFund\"[\n\x16\x45ventRequestRedemption\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionSchedule\"\x92\x01\n\x17\x45ventWithdrawRedemption\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionSchedule\x12\x34\n\x0bredeem_coin\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x9b\x01\n\x0f\x45ventUnderwrite\x12\x13\n\x0bunderwriter\x18\x01 \x01(\t\x12\x10\n\x08marketId\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12/\n\x06shares\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x42QZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,])




_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.insurance.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_redemption_notice_period_duration', full_name='injective.insurance.v1beta1.Params.default_redemption_notice_period_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\230\337\037\001\310\336\037\000\362\336\0370yaml:\"default_redemption_notice_period_duration\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=390,
)


_INSURANCEFUND = _descriptor.Descriptor(
  name='InsuranceFund',
  full_name='injective.insurance.v1beta1.InsuranceFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposit_denom', full_name='injective.insurance.v1beta1.InsuranceFund.deposit_denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insurance_pool_token_denom', full_name='injective.insurance.v1beta1.InsuranceFund.insurance_pool_token_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_notice_period_duration', full_name='injective.insurance.v1beta1.InsuranceFund.redemption_notice_period_duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\230\337\037\001\310\336\037\000\362\336\037(yaml:\"redemption_notice_period_duration\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='injective.insurance.v1beta1.InsuranceFund.balance', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_share', full_name='injective.insurance.v1beta1.InsuranceFund.total_share', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.insurance.v1beta1.InsuranceFund.market_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ticker', full_name='injective.insurance.v1beta1.InsuranceFund.market_ticker', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.insurance.v1beta1.InsuranceFund.oracle_base', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.insurance.v1beta1.InsuranceFund.oracle_quote', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.insurance.v1beta1.InsuranceFund.oracle_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective.insurance.v1beta1.InsuranceFund.expiry', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=885,
)


_REDEMPTIONSCHEDULE = _descriptor.Descriptor(
  name='RedemptionSchedule',
  full_name='injective.insurance.v1beta1.RedemptionSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='injective.insurance.v1beta1.RedemptionSchedule.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketId', full_name='injective.insurance.v1beta1.RedemptionSchedule.marketId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redeemer', full_name='injective.insurance.v1beta1.RedemptionSchedule.redeemer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claimable_redemption_time', full_name='injective.insurance.v1beta1.RedemptionSchedule.claimable_redemption_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\337\037\001\310\336\037\000\362\336\037 yaml:\"claimable_redemption_time\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_amount', full_name='injective.insurance.v1beta1.RedemptionSchedule.redemption_amount', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=1125,
)


_EVENTINSURANCEFUNDUPDATE = _descriptor.Descriptor(
  name='EventInsuranceFundUpdate',
  full_name='injective.insurance.v1beta1.EventInsuranceFundUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fund', full_name='injective.insurance.v1beta1.EventInsuranceFundUpdate.fund', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1211,
)


_EVENTREQUESTREDEMPTION = _descriptor.Descriptor(
  name='EventRequestRedemption',
  full_name='injective.insurance.v1beta1.EventRequestRedemption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='injective.insurance.v1beta1.EventRequestRedemption.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1213,
  serialized_end=1304,
)


_EVENTWITHDRAWREDEMPTION = _descriptor.Descriptor(
  name='EventWithdrawRedemption',
  full_name='injective.insurance.v1beta1.EventWithdrawRedemption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='injective.insurance.v1beta1.EventWithdrawRedemption.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redeem_coin', full_name='injective.insurance.v1beta1.EventWithdrawRedemption.redeem_coin', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1453,
)


_EVENTUNDERWRITE = _descriptor.Descriptor(
  name='EventUnderwrite',
  full_name='injective.insurance.v1beta1.EventUnderwrite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='underwriter', full_name='injective.insurance.v1beta1.EventUnderwrite.underwriter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketId', full_name='injective.insurance.v1beta1.EventUnderwrite.marketId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='injective.insurance.v1beta1.EventUnderwrite.deposit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shares', full_name='injective.insurance.v1beta1.EventUnderwrite.shares', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1611,
)

_PARAMS.fields_by_name['default_redemption_notice_period_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_INSURANCEFUND.fields_by_name['redemption_notice_period_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_INSURANCEFUND.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_REDEMPTIONSCHEDULE.fields_by_name['claimable_redemption_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REDEMPTIONSCHEDULE.fields_by_name['redemption_amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTINSURANCEFUNDUPDATE.fields_by_name['fund'].message_type = _INSURANCEFUND
_EVENTREQUESTREDEMPTION.fields_by_name['schedule'].message_type = _REDEMPTIONSCHEDULE
_EVENTWITHDRAWREDEMPTION.fields_by_name['schedule'].message_type = _REDEMPTIONSCHEDULE
_EVENTWITHDRAWREDEMPTION.fields_by_name['redeem_coin'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTUNDERWRITE.fields_by_name['deposit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTUNDERWRITE.fields_by_name['shares'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['InsuranceFund'] = _INSURANCEFUND
DESCRIPTOR.message_types_by_name['RedemptionSchedule'] = _REDEMPTIONSCHEDULE
DESCRIPTOR.message_types_by_name['EventInsuranceFundUpdate'] = _EVENTINSURANCEFUNDUPDATE
DESCRIPTOR.message_types_by_name['EventRequestRedemption'] = _EVENTREQUESTREDEMPTION
DESCRIPTOR.message_types_by_name['EventWithdrawRedemption'] = _EVENTWITHDRAWREDEMPTION
DESCRIPTOR.message_types_by_name['EventUnderwrite'] = _EVENTUNDERWRITE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

InsuranceFund = _reflection.GeneratedProtocolMessageType('InsuranceFund', (_message.Message,), {
  'DESCRIPTOR' : _INSURANCEFUND,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.InsuranceFund)
  })
_sym_db.RegisterMessage(InsuranceFund)

RedemptionSchedule = _reflection.GeneratedProtocolMessageType('RedemptionSchedule', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSCHEDULE,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.RedemptionSchedule)
  })
_sym_db.RegisterMessage(RedemptionSchedule)

EventInsuranceFundUpdate = _reflection.GeneratedProtocolMessageType('EventInsuranceFundUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTINSURANCEFUNDUPDATE,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventInsuranceFundUpdate)
  })
_sym_db.RegisterMessage(EventInsuranceFundUpdate)

EventRequestRedemption = _reflection.GeneratedProtocolMessageType('EventRequestRedemption', (_message.Message,), {
  'DESCRIPTOR' : _EVENTREQUESTREDEMPTION,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventRequestRedemption)
  })
_sym_db.RegisterMessage(EventRequestRedemption)

EventWithdrawRedemption = _reflection.GeneratedProtocolMessageType('EventWithdrawRedemption', (_message.Message,), {
  'DESCRIPTOR' : _EVENTWITHDRAWREDEMPTION,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventWithdrawRedemption)
  })
_sym_db.RegisterMessage(EventWithdrawRedemption)

EventUnderwrite = _reflection.GeneratedProtocolMessageType('EventUnderwrite', (_message.Message,), {
  'DESCRIPTOR' : _EVENTUNDERWRITE,
  '__module__' : 'injective.insurance.v1beta1.insurance_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.EventUnderwrite)
  })
_sym_db.RegisterMessage(EventUnderwrite)


DESCRIPTOR._options = None
_PARAMS.fields_by_name['default_redemption_notice_period_duration']._options = None
_PARAMS._options = None
_INSURANCEFUND.fields_by_name['redemption_notice_period_duration']._options = None
_INSURANCEFUND.fields_by_name['balance']._options = None
_INSURANCEFUND.fields_by_name['total_share']._options = None
_REDEMPTIONSCHEDULE.fields_by_name['claimable_redemption_time']._options = None
_REDEMPTIONSCHEDULE.fields_by_name['redemption_amount']._options = None
_EVENTWITHDRAWREDEMPTION.fields_by_name['redeem_coin']._options = None
_EVENTUNDERWRITE.fields_by_name['deposit']._options = None
_EVENTUNDERWRITE.fields_by_name['shares']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/oracle/v1beta1/genesis.proto',
  package='injective.oracle.v1beta1',
  syntax='proto3',
  serialized_options=b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&injective/oracle/v1beta1/genesis.proto\x12\x18injective.oracle.v1beta1\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"\x80\x07\n\x0cGenesisState\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x15\n\rband_relayers\x18\x02 \x03(\t\x12\x43\n\x11\x62\x61nd_price_states\x18\x03 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\x12I\n\x17price_feed_price_states\x18\x04 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedState\x12K\n\x15\x63oinbase_price_states\x18\x05 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceState\x12G\n\x15\x62\x61nd_ibc_price_states\x18\x06 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\x12M\n\x18\x62\x61nd_ibc_oracle_requests\x18\x07 \x03(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequest\x12\x46\n\x0f\x62\x61nd_ibc_params\x18\x08 \x01(\x0b\x32\'.injective.oracle.v1beta1.BandIBCParamsB\x04\xc8\xde\x1f\x00\x12!\n\x19\x62\x61nd_ibc_latest_client_id\x18\t \x01(\x04\x12\x42\n\x10\x63\x61lldata_records\x18\n \x03(\x0b\x32(.injective.oracle.v1beta1.CalldataRecord\x12\"\n\x1a\x62\x61nd_ibc_latest_request_id\x18\x0b \x01(\x04\x12M\n\x16\x63hainlink_price_states\x18\x0c \x03(\x0b\x32-.injective.oracle.v1beta1.ChainlinkPriceState\x12H\n\x18historical_price_records\x18\r \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecords\x12@\n\x0fprovider_states\x18\x0e \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderState\"5\n\x0e\x43\x61lldataRecord\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\x0c\x42NZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3'
  ,
  dependencies=[injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='injective.oracle.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.oracle.v1beta1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_relayers', full_name='injective.oracle.v1beta1.GenesisState.band_relayers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_price_states', full_name='injective.oracle.v1beta1.GenesisState.band_price_states', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_feed_price_states', full_name='injective.oracle.v1beta1.GenesisState.price_feed_price_states', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coinbase_price_states', full_name='injective.oracle.v1beta1.GenesisState.coinbase_price_states', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_ibc_price_states', full_name='injective.oracle.v1beta1.GenesisState.band_ibc_price_states', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_ibc_oracle_requests', full_name='injective.oracle.v1beta1.GenesisState.band_ibc_oracle_requests', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_ibc_params', full_name='injective.oracle.v1beta1.GenesisState.band_ibc_params', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_ibc_latest_client_id', full_name='injective.oracle.v1beta1.GenesisState.band_ibc_latest_client_id', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata_records', full_name='injective.oracle.v1beta1.GenesisState.calldata_records', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_ibc_latest_request_id', full_name='injective.oracle.v1beta1.GenesisState.band_ibc_latest_request_id', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chainlink_price_states', full_name='injective.oracle.v1beta1.GenesisState.chainlink_price_states', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historical_price_records', full_name='injective.oracle.v1beta1.GenesisState.historical_price_records', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_states', full_name='injective.oracle.v1beta1.GenesisState.provider_states', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=1026,
)


_CALLDATARECORD = _descriptor.Descriptor(
  name='CalldataRecord',
  full_name='injective.oracle.v1beta1.CalldataRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.CalldataRecord.client_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='injective.oracle.v1beta1.CalldataRecord.calldata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1028,
  serialized_end=1081,
)

_GENESISSTATE.fields_by_name['params'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PARAMS
_GENESISSTATE.fields_by_name['band_price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._BANDPRICESTATE
_GENESISSTATE.fields_by_name['price_feed_price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PRICEFEEDSTATE
_GENESISSTATE.fields_by_name['coinbase_price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._COINBASEPRICESTATE
_GENESISSTATE.fields_by_name['band_ibc_price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._BANDPRICESTATE
_GENESISSTATE.fields_by_name['band_ibc_oracle_requests'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._BANDORACLEREQUEST
_GENESISSTATE.fields_by_name['band_ibc_params'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._BANDIBCPARAMS
_GENESISSTATE.fields_by_name['calldata_records'].message_type = _CALLDATARECORD
_GENESISSTATE.fields_by_name['chainlink_price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._CHAINLINKPRICESTATE
_GENESISSTATE.fields_by_name['historical_price_records'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PRICERECORDS
_GENESISSTATE.fields_by_name['provider_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PROVIDERSTATE
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
DESCRIPTOR.message_types_by_name['CalldataRecord'] = _CALLDATARECORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'injective.oracle.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

CalldataRecord = _reflection.GeneratedProtocolMessageType('CalldataRecord', (_message.Message,), {
  'DESCRIPTOR' : _CALLDATARECORD,
  '__module__' : 'injective.oracle.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.CalldataRecord)
  })
_sym_db.RegisterMessage(CalldataRecord)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['params']._options = None
_GENESISSTATE.fields_by_name['band_ibc_params']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/types/v1beta1/tx_response.proto',
  package='injective.types.v1beta1',
  syntax='proto3',
  serialized_options=b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)injective/types/v1beta1/tx_response.proto\x12\x17injective.types.v1beta1\"8\n\x18TxResponseGenericMessage\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"U\n\x0eTxResponseData\x12\x43\n\x08messages\x18\x01 \x03(\x0b\x32\x31.injective.types.v1beta1.TxResponseGenericMessageB?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3'
)




_TXRESPONSEGENERICMESSAGE = _descriptor.Descriptor(
  name='TxResponseGenericMessage',
  full_name='injective.types.v1beta1.TxResponseGenericMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='injective.types.v1beta1.TxResponseGenericMessage.header', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.types.v1beta1.TxResponseGenericMessage.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=126,
)


_TXRESPONSEDATA = _descriptor.Descriptor(
  name='TxResponseData',
  full_name='injective.types.v1beta1.TxResponseData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='injective.types.v1beta1.TxResponseData.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=213,
)

_TXRESPONSEDATA.fields_by_name['messages'].message_type = _TXRESPONSEGENERICMESSAGE
DESCRIPTOR.message_types_by_name['TxResponseGenericMessage'] = _TXRESPONSEGENERICMESSAGE
DESCRIPTOR.message_types_by_name['TxResponseData'] = _TXRESPONSEDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TxResponseGenericMessage = _reflection.GeneratedProtocolMessageType('TxResponseGenericMessage', (_message.Message,), {
  'DESCRIPTOR' : _TXRESPONSEGENERICMESSAGE,
  '__module__' : 'injective.types.v1beta1.tx_response_pb2'
  # @@protoc_insertion_point(class_scope:injective.types.v1beta1.TxResponseGenericMessage)
  })
_sym_db.RegisterMessage(TxResponseGenericMessage)

TxResponseData = _reflection.GeneratedProtocolMessageType('TxResponseData', (_message.Message,), {
  'DESCRIPTOR' : _TXRESPONSEDATA,
  '__module__' : 'injective.types.v1beta1.tx_response_pb2'
  # @@protoc_insertion_point(class_scope:injective.types.v1beta1.TxResponseData)
  })
_sym_db.RegisterMessage(TxResponseData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import sha3
import requests
from decimal import Decimal
from eip712_structs import make_domain, EIP712Struct, String

class OrderInfo(EIP712Struct):
    SubaccountId = String()
    FeeRecipient = String()
    Price = String()
    Quantity = String()

class SpotOrder(EIP712Struct):
    MarketId = String()
    OrderInfo = OrderInfo
    Salt = String()
    OrderType = String()
    TriggerPrice = String()

class DerivativeOrder(EIP712Struct):
    MarketId = String()
    OrderInfo = OrderInfo
    OrderType = String()
    Margin = String()
    TriggerPrice = String()
    Salt = String()

EIP712_domain = make_domain(
    name='Injective Protocol',
    version='2.0.0',
    chainId=888,
    verifyingContract='0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC',
    salt='0x0000000000000000000000000000000000000000000000000000000000000000'
)

domain_separator = EIP712_domain.hash_struct()
order_type_dict = {0: '\x00', 1: '\x01', 2: '\x02', 3: '\x03', 4: '\x04', 5: '\x05', 6: '\x06', 7: '\x07', 8: '\x08'}

class OrderHashResponse:
    def __init__(
            self,
            spot: [str] = None,
            derivative: [str] = None,
    ):
        self.spot = spot
        self.derivative = derivative

class OrderHashManager:
    def __init__(
            self,
            address,
            network,
            subaccount_indexes: [int] = None,
    ):
        self.address = address
        self.subacc_nonces = dict()

        for i in subaccount_indexes:
            subaccount_id = address.get_subaccount_id(index=i)
            url = network.lcd_endpoint + '/injective/exchange/v1beta1/exchange/' + subaccount_id
            res = requests.get(url=url)
            nonce = res.json()["nonce"]
            self.subacc_nonces[i] = [subaccount_id, nonce + 1]

    def compute_order_hashes(self, spot_orders, derivative_orders, subaccount_index) -> [str]:
        if len(spot_orders) + len(derivative_orders) == 0:
            return []

        order_hashes = OrderHashResponse(spot=[], derivative=[])

        for o in spot_orders:
            msg = build_eip712_msg(o, self.subacc_nonces[subaccount_index][1])
            order_hash = hash_order(msg)
            order_hashes.spot.append(order_hash)
            self.subacc_nonces[subaccount_index][1] += 1

        for o in derivative_orders:
            msg = build_eip712_msg(o, self.subacc_nonces[subaccount_index][1])
            order_hash = hash_order(msg)
            order_hashes.derivative.append(order_hash)
            self.subacc_nonces[subaccount_index][1] += 1

        return order_hashes

def param_to_backend_go(param) -> int:
    go_param = Decimal(param) / pow(10, 18)
    return format(go_param, '.18f')

def parse_order_type(order):
    return order_type_dict[order.order_type]

def build_eip712_msg(order, nonce):
    if order.__class__.__name__ == 'SpotOrder':
        go_price = param_to_backend_go(order.order_info.price)
        go_trigger_price = param_to_backend_go(order.trigger_price)
        go_quantity = param_to_backend_go(order.order_info.quantity)
        go_order_type = parse_order_type(order)
        return SpotOrder(
            MarketId=order.market_id,
            OrderInfo=OrderInfo(
                SubaccountId=order.order_info.subaccount_id,
                FeeRecipient=order.order_info.fee_recipient,
                Price=go_price,
                Quantity=go_quantity
            ),
            Salt=str(nonce),
            OrderType=go_order_type,
            TriggerPrice=go_trigger_price
        )
    if order.__class__.__name__ == 'DerivativeOrder':
        go_price = param_to_backend_go(order.order_info.price)
        go_trigger_price = param_to_backend_go(order.trigger_price)
        go_quantity = param_to_backend_go(order.order_info.quantity)
        go_margin = param_to_backend_go(order.margin)
        go_order_type = parse_order_type(order)
        return DerivativeOrder(
            MarketId=order.market_id,
            OrderInfo=OrderInfo(
                SubaccountId=order.order_info.subaccount_id,
                FeeRecipient=order.order_info.fee_recipient,
                Price=go_price,
                Quantity=go_quantity
            ),
            Salt=str(nonce),
            OrderType=go_order_type,
            TriggerPrice=go_trigger_price,
            Margin=go_margin
        )

def hash_order(msg):
    typed_data_hash = msg.hash_struct()
    typed_bytes = b'\x19\x01' + domain_separator + typed_data_hash
    keccak256 = sha3.keccak_256()
    keccak256.update(typed_bytes)
    return '0x' + keccak256.hexdigest()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/consensus/wal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.consensus import types_pb2 as tendermint_dot_consensus_dot_types__pb2
from tendermint.types import events_pb2 as tendermint_dot_types_dot_events__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/consensus/wal.proto',
  package='tendermint.consensus',
  syntax='proto3',
  serialized_options=b'Z;github.com/tendermint/tendermint/proto/tendermint/consensus',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etendermint/consensus/wal.proto\x12\x14tendermint.consensus\x1a\x14gogoproto/gogo.proto\x1a tendermint/consensus/types.proto\x1a\x1dtendermint/types/events.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"X\n\x07MsgInfo\x12\x30\n\x03msg\x18\x01 \x01(\x0b\x32\x1d.tendermint.consensus.MessageB\x04\xc8\xde\x1f\x00\x12\x1b\n\x07peer_id\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06PeerID\"q\n\x0bTimeoutInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x0c\n\x04step\x18\x04 \x01(\r\"\x1b\n\tEndHeight\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x81\x02\n\nWALMessage\x12G\n\x16\x65vent_data_round_state\x18\x01 \x01(\x0b\x32%.tendermint.types.EventDataRoundStateH\x00\x12\x31\n\x08msg_info\x18\x02 \x01(\x0b\x32\x1d.tendermint.consensus.MsgInfoH\x00\x12\x39\n\x0ctimeout_info\x18\x03 \x01(\x0b\x32!.tendermint.consensus.TimeoutInfoH\x00\x12\x35\n\nend_height\x18\x04 \x01(\x0b\x32\x1f.tendermint.consensus.EndHeightH\x00\x42\x05\n\x03sum\"t\n\x0fTimedWALMessage\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12-\n\x03msg\x18\x02 \x01(\x0b\x32 .tendermint.consensus.WALMessageB=Z;github.com/tendermint/tendermint/proto/tendermint/consensusb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,tendermint_dot_consensus_dot_types__pb2.DESCRIPTOR,tendermint_dot_types_dot_events__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_MSGINFO = _descriptor.Descriptor(
  name='MsgInfo',
  full_name='tendermint.consensus.MsgInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='tendermint.consensus.MsgInfo.msg', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='tendermint.consensus.MsgInfo.peer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\006PeerID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=296,
)


_TIMEOUTINFO = _descriptor.Descriptor(
  name='TimeoutInfo',
  full_name='tendermint.consensus.TimeoutInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='tendermint.consensus.TimeoutInfo.duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\230\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.TimeoutInfo.height', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.consensus.TimeoutInfo.round', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='tendermint.consensus.TimeoutInfo.step', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=411,
)


_ENDHEIGHT = _descriptor.Descriptor(
  name='EndHeight',
  full_name='tendermint.consensus.EndHeight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.consensus.EndHeight.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=440,
)


_WALMESSAGE = _descriptor.Descriptor(
  name='WALMessage',
  full_name='tendermint.consensus.WALMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_data_round_state', full_name='tendermint.consensus.WALMessage.event_data_round_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_info', full_name='tendermint.consensus.WALMessage.msg_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_info', full_name='tendermint.consensus.WALMessage.timeout_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_height', full_name='tendermint.consensus.WALMessage.end_height', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.consensus.WALMessage.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=443,
  serialized_end=700,
)


_TIMEDWALMESSAGE = _descriptor.Descriptor(
  name='TimedWALMessage',
  full_name='tendermint.consensus.TimedWALMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='tendermint.consensus.TimedWALMessage.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\220\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='tendermint.consensus.TimedWALMessage.msg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=818,
)

_MSGINFO.fields_by_name['msg'].message_type = tendermint_dot_consensus_dot_types__pb2._MESSAGE
_TIMEOUTINFO.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WALMESSAGE.fields_by_name['event_data_round_state'].message_type = tendermint_dot_types_dot_events__pb2._EVENTDATAROUNDSTATE
_WALMESSAGE.fields_by_name['msg_info'].message_type = _MSGINFO
_WALMESSAGE.fields_by_name['timeout_info'].message_type = _TIMEOUTINFO
_WALMESSAGE.fields_by_name['end_height'].message_type = _ENDHEIGHT
_WALMESSAGE.oneofs_by_name['sum'].fields.append(
  _WALMESSAGE.fields_by_name['event_data_round_state'])
_WALMESSAGE.fields_by_name['event_data_round_state'].containing_oneof = _WALMESSAGE.oneofs_by_name['sum']
_WALMESSAGE.oneofs_by_name['sum'].fields.append(
  _WALMESSAGE.fields_by_name['msg_info'])
_WALMESSAGE.fields_by_name['msg_info'].containing_oneof = _WALMESSAGE.oneofs_by_name['sum']
_WALMESSAGE.oneofs_by_name['sum'].fields.append(
  _WALMESSAGE.fields_by_name['timeout_info'])
_WALMESSAGE.fields_by_name['timeout_info'].containing_oneof = _WALMESSAGE.oneofs_by_name['sum']
_WALMESSAGE.oneofs_by_name['sum'].fields.append(
  _WALMESSAGE.fields_by_name['end_height'])
_WALMESSAGE.fields_by_name['end_height'].containing_oneof = _WALMESSAGE.oneofs_by_name['sum']
_TIMEDWALMESSAGE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEDWALMESSAGE.fields_by_name['msg'].message_type = _WALMESSAGE
DESCRIPTOR.message_types_by_name['MsgInfo'] = _MSGINFO
DESCRIPTOR.message_types_by_name['TimeoutInfo'] = _TIMEOUTINFO
DESCRIPTOR.message_types_by_name['EndHeight'] = _ENDHEIGHT
DESCRIPTOR.message_types_by_name['WALMessage'] = _WALMESSAGE
DESCRIPTOR.message_types_by_name['TimedWALMessage'] = _TIMEDWALMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgInfo = _reflection.GeneratedProtocolMessageType('MsgInfo', (_message.Message,), {
  'DESCRIPTOR' : _MSGINFO,
  '__module__' : 'tendermint.consensus.wal_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.MsgInfo)
  })
_sym_db.RegisterMessage(MsgInfo)

TimeoutInfo = _reflection.GeneratedProtocolMessageType('TimeoutInfo', (_message.Message,), {
  'DESCRIPTOR' : _TIMEOUTINFO,
  '__module__' : 'tendermint.consensus.wal_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.TimeoutInfo)
  })
_sym_db.RegisterMessage(TimeoutInfo)

EndHeight = _reflection.GeneratedProtocolMessageType('EndHeight', (_message.Message,), {
  'DESCRIPTOR' : _ENDHEIGHT,
  '__module__' : 'tendermint.consensus.wal_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.EndHeight)
  })
_sym_db.RegisterMessage(EndHeight)

WALMessage = _reflection.GeneratedProtocolMessageType('WALMessage', (_message.Message,), {
  'DESCRIPTOR' : _WALMESSAGE,
  '__module__' : 'tendermint.consensus.wal_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.WALMessage)
  })
_sym_db.RegisterMessage(WALMessage)

TimedWALMessage = _reflection.GeneratedProtocolMessageType('TimedWALMessage', (_message.Message,), {
  'DESCRIPTOR' : _TIMEDWALMESSAGE,
  '__module__' : 'tendermint.consensus.wal_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.consensus.TimedWALMessage)
  })
_sym_db.RegisterMessage(TimedWALMessage)


DESCRIPTOR._options = None
_MSGINFO.fields_by_name['msg']._options = None
_MSGINFO.fields_by_name['peer_id']._options = None
_TIMEOUTINFO.fields_by_name['duration']._options = None
_TIMEDWALMESSAGE.fields_by_name['time']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/vesting/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/vesting/v1beta1/tx.proto',
  package='cosmos.vesting.v1beta1',
  syntax='proto3',
  serialized_options=b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x63osmos/vesting/v1beta1/tx.proto\x12\x16\x63osmos.vesting.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x8e\x02\n\x17MsgCreateVestingAccount\x12-\n\x0c\x66rom_address\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"from_address\"\x12)\n\nto_address\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"to_address\"\x12[\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12%\n\x08\x65nd_time\x18\x04 \x01(\x03\x42\x13\xf2\xde\x1f\x0fyaml:\"end_time\"\x12\x0f\n\x07\x64\x65layed\x18\x05 \x01(\x08:\x04\xe8\xa0\x1f\x01\"!\n\x1fMsgCreateVestingAccountResponse2\x88\x01\n\x03Msg\x12\x80\x01\n\x14\x43reateVestingAccount\x12/.cosmos.vesting.v1beta1.MsgCreateVestingAccount\x1a\x37.cosmos.vesting.v1beta1.MsgCreateVestingAccountResponseB3Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_MSGCREATEVESTINGACCOUNT = _descriptor.Descriptor(
  name='MsgCreateVestingAccount',
  full_name='cosmos.vesting.v1beta1.MsgCreateVestingAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_address', full_name='cosmos.vesting.v1beta1.MsgCreateVestingAccount.from_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"from_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_address', full_name='cosmos.vesting.v1beta1.MsgCreateVestingAccount.to_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"to_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='cosmos.vesting.v1beta1.MsgCreateVestingAccount.amount', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='cosmos.vesting.v1beta1.MsgCreateVestingAccount.end_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\017yaml:\"end_time\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed', full_name='cosmos.vesting.v1beta1.MsgCreateVestingAccount.delayed', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=384,
)


_MSGCREATEVESTINGACCOUNTRESPONSE = _descriptor.Descriptor(
  name='MsgCreateVestingAccountResponse',
  full_name='cosmos.vesting.v1beta1.MsgCreateVestingAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=419,
)

_MSGCREATEVESTINGACCOUNT.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgCreateVestingAccount'] = _MSGCREATEVESTINGACCOUNT
DESCRIPTOR.message_types_by_name['MsgCreateVestingAccountResponse'] = _MSGCREATEVESTINGACCOUNTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgCreateVestingAccount = _reflection.GeneratedProtocolMessageType('MsgCreateVestingAccount', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEVESTINGACCOUNT,
  '__module__' : 'cosmos.vesting.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.vesting.v1beta1.MsgCreateVestingAccount)
  })
_sym_db.RegisterMessage(MsgCreateVestingAccount)

MsgCreateVestingAccountResponse = _reflection.GeneratedProtocolMessageType('MsgCreateVestingAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEVESTINGACCOUNTRESPONSE,
  '__module__' : 'cosmos.vesting.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.vesting.v1beta1.MsgCreateVestingAccountResponse)
  })
_sym_db.RegisterMessage(MsgCreateVestingAccountResponse)


DESCRIPTOR._options = None
_MSGCREATEVESTINGACCOUNT.fields_by_name['from_address']._options = None
_MSGCREATEVESTINGACCOUNT.fields_by_name['to_address']._options = None
_MSGCREATEVESTINGACCOUNT.fields_by_name['amount']._options = None
_MSGCREATEVESTINGACCOUNT.fields_by_name['end_time']._options = None
_MSGCREATEVESTINGACCOUNT._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='cosmos.vesting.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=422,
  serialized_end=558,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateVestingAccount',
    full_name='cosmos.vesting.v1beta1.Msg.CreateVestingAccount',
    index=0,
    containing_service=None,
    input_type=_MSGCREATEVESTINGACCOUNT,
    output_type=_MSGCREATEVESTINGACCOUNTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v1/solomachine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/lightclients/solomachine/v1/solomachine.proto',
  package='ibc.lightclients.solomachine.v1',
  syntax='proto3',
  serialized_options=b'Z>github.com/cosmos/ibc-go/v2/modules/core/02-client/legacy/v100',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1ibc/lightclients/solomachine/v1/solomachine.proto\x12\x1fibc.lightclients.solomachine.v1\x1a\'ibc/core/connection/v1/connection.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\x8d\x02\n\x0b\x43lientState\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x33\n\x0f\x66rozen_sequence\x18\x02 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"frozen_sequence\"\x12\x64\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v1.ConsensusStateB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\"\x12K\n\x1b\x61llow_update_after_proposal\x18\x04 \x01(\x08\x42&\xf2\xde\x1f\"yaml:\"allow_update_after_proposal\":\x04\x88\xa0\x1f\x00\"\x7f\n\x0e\x43onsensusState\x12?\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x15\xf2\xde\x1f\x11yaml:\"public_key\"\x12\x13\n\x0b\x64iversifier\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04:\x04\x88\xa0\x1f\x00\"\xc4\x01\n\x06Header\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12G\n\x0enew_public_key\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\xf2\xde\x1f\x15yaml:\"new_public_key\"\x12\x33\n\x0fnew_diversifier\x18\x05 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\"\x97\x02\n\x0cMisbehaviour\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12\x62\n\rsignature_one\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v1.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_one\"\x12\x62\n\rsignature_two\x18\x04 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v1.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_two\":\x04\x88\xa0\x1f\x00\"\xa0\x01\n\x10SignatureAndData\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12R\n\tdata_type\x18\x02 \x01(\x0e\x32).ibc.lightclients.solomachine.v1.DataTypeB\x14\xf2\xde\x1f\x10yaml:\"data_type\"\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x04:\x04\x88\xa0\x1f\x00\"f\n\x18TimestampedSignatureData\x12\x31\n\x0esignature_data\x18\x01 \x01(\x0c\x42\x19\xf2\xde\x1f\x15yaml:\"signature_data\"\x12\x11\n\ttimestamp\x18\x02 \x01(\x04:\x04\x88\xa0\x1f\x00\"\xad\x01\n\tSignBytes\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0b\x64iversifier\x18\x03 \x01(\t\x12R\n\tdata_type\x18\x04 \x01(\x0e\x32).ibc.lightclients.solomachine.v1.DataTypeB\x14\xf2\xde\x1f\x10yaml:\"data_type\"\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c:\x04\x88\xa0\x1f\x00\"\x8a\x01\n\nHeaderData\x12\x41\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x16\xf2\xde\x1f\x12yaml:\"new_pub_key\"\x12\x33\n\x0fnew_diversifier\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\"j\n\x0f\x43lientStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x43\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\":\x04\x88\xa0\x1f\x00\"s\n\x12\x43onsensusStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12I\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\":\x04\x88\xa0\x1f\x00\"d\n\x13\x43onnectionStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x39\n\nconnection\x18\x02 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEnd:\x04\x88\xa0\x1f\x00\"U\n\x10\x43hannelStateData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12-\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.Channel:\x04\x88\xa0\x1f\x00\"8\n\x14PacketCommitmentData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x12\n\ncommitment\x18\x02 \x01(\x0c\"B\n\x19PacketAcknowledgementData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\"(\n\x18PacketReceiptAbsenceData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\"U\n\x14NextSequenceRecvData\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12/\n\rnext_seq_recv\x18\x02 \x01(\x04\x42\x18\xf2\xde\x1f\x14yaml:\"next_seq_recv\"*\x8c\x04\n\x08\x44\x61taType\x12\x38\n#DATA_TYPE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12&\n\x16\x44\x41TA_TYPE_CLIENT_STATE\x10\x01\x1a\n\x8a\x9d \x06\x43LIENT\x12,\n\x19\x44\x41TA_TYPE_CONSENSUS_STATE\x10\x02\x1a\r\x8a\x9d \tCONSENSUS\x12.\n\x1a\x44\x41TA_TYPE_CONNECTION_STATE\x10\x03\x1a\x0e\x8a\x9d \nCONNECTION\x12(\n\x17\x44\x41TA_TYPE_CHANNEL_STATE\x10\x04\x1a\x0b\x8a\x9d \x07\x43HANNEL\x12\x35\n\x1b\x44\x41TA_TYPE_PACKET_COMMITMENT\x10\x05\x1a\x14\x8a\x9d \x10PACKETCOMMITMENT\x12?\n DATA_TYPE_PACKET_ACKNOWLEDGEMENT\x10\x06\x1a\x19\x8a\x9d \x15PACKETACKNOWLEDGEMENT\x12>\n DATA_TYPE_PACKET_RECEIPT_ABSENCE\x10\x07\x1a\x18\x8a\x9d \x14PACKETRECEIPTABSENCE\x12\x36\n\x1c\x44\x41TA_TYPE_NEXT_SEQUENCE_RECV\x10\x08\x1a\x14\x8a\x9d \x10NEXTSEQUENCERECV\x12 \n\x10\x44\x41TA_TYPE_HEADER\x10\t\x1a\n\x8a\x9d \x06HEADER\x1a\x04\x88\xa3\x1e\x00\x42@Z>github.com/cosmos/ibc-go/v2/modules/core/02-client/legacy/v100b\x06proto3'
  ,
  dependencies=[ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2.DESCRIPTOR,ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='ibc.lightclients.solomachine.v1.DataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_UNINITIALIZED_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \013UNSPECIFIED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CLIENT_STATE', index=1, number=1,
      serialized_options=b'\212\235 \006CLIENT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CONSENSUS_STATE', index=2, number=2,
      serialized_options=b'\212\235 \tCONSENSUS',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CONNECTION_STATE', index=3, number=3,
      serialized_options=b'\212\235 \nCONNECTION',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_CHANNEL_STATE', index=4, number=4,
      serialized_options=b'\212\235 \007CHANNEL',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_PACKET_COMMITMENT', index=5, number=5,
      serialized_options=b'\212\235 \020PACKETCOMMITMENT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_PACKET_ACKNOWLEDGEMENT', index=6, number=6,
      serialized_options=b'\212\235 \025PACKETACKNOWLEDGEMENT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_PACKET_RECEIPT_ABSENCE', index=7, number=7,
      serialized_options=b'\212\235 \024PACKETRECEIPTABSENCE',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_NEXT_SEQUENCE_RECV', index=8, number=8,
      serialized_options=b'\212\235 \020NEXTSEQUENCERECV',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_HEADER', index=9, number=9,
      serialized_options=b'\212\235 \006HEADER',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=2347,
  serialized_end=2871,
)
_sym_db.RegisterEnumDescriptor(_DATATYPE)

DataType = enum_type_wrapper.EnumTypeWrapper(_DATATYPE)
DATA_TYPE_UNINITIALIZED_UNSPECIFIED = 0
DATA_TYPE_CLIENT_STATE = 1
DATA_TYPE_CONSENSUS_STATE = 2
DATA_TYPE_CONNECTION_STATE = 3
DATA_TYPE_CHANNEL_STATE = 4
DATA_TYPE_PACKET_COMMITMENT = 5
DATA_TYPE_PACKET_ACKNOWLEDGEMENT = 6
DATA_TYPE_PACKET_RECEIPT_ABSENCE = 7
DATA_TYPE_NEXT_SEQUENCE_RECV = 8
DATA_TYPE_HEADER = 9



_CLIENTSTATE = _descriptor.Descriptor(
  name='ClientState',
  full_name='ibc.lightclients.solomachine.v1.ClientState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.ClientState.sequence', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frozen_sequence', full_name='ibc.lightclients.solomachine.v1.ClientState.frozen_sequence', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"frozen_sequence\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_state', full_name='ibc.lightclients.solomachine.v1.ClientState.consensus_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"consensus_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_update_after_proposal', full_name='ibc.lightclients.solomachine.v1.ClientState.allow_update_after_proposal', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\"yaml:\"allow_update_after_proposal\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=481,
)


_CONSENSUSSTATE = _descriptor.Descriptor(
  name='ConsensusState',
  full_name='ibc.lightclients.solomachine.v1.ConsensusState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='ibc.lightclients.solomachine.v1.ConsensusState.public_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"public_key\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diversifier', full_name='ibc.lightclients.solomachine.v1.ConsensusState.diversifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.ConsensusState.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=610,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='ibc.lightclients.solomachine.v1.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.Header.sequence', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.Header.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='ibc.lightclients.solomachine.v1.Header.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_public_key', full_name='ibc.lightclients.solomachine.v1.Header.new_public_key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"new_public_key\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_diversifier', full_name='ibc.lightclients.solomachine.v1.Header.new_diversifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"new_diversifier\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=809,
)


_MISBEHAVIOUR = _descriptor.Descriptor(
  name='Misbehaviour',
  full_name='ibc.lightclients.solomachine.v1.Misbehaviour',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"client_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.sequence', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature_one', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.signature_one', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"signature_one\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature_two', full_name='ibc.lightclients.solomachine.v1.Misbehaviour.signature_two', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"signature_two\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=1091,
)


_SIGNATUREANDDATA = _descriptor.Descriptor(
  name='SignatureAndData',
  full_name='ibc.lightclients.solomachine.v1.SignatureAndData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.signature', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.data_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"data_type\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.SignatureAndData.timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1254,
)


_TIMESTAMPEDSIGNATUREDATA = _descriptor.Descriptor(
  name='TimestampedSignatureData',
  full_name='ibc.lightclients.solomachine.v1.TimestampedSignatureData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature_data', full_name='ibc.lightclients.solomachine.v1.TimestampedSignatureData.signature_data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"signature_data\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.TimestampedSignatureData.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1358,
)


_SIGNBYTES = _descriptor.Descriptor(
  name='SignBytes',
  full_name='ibc.lightclients.solomachine.v1.SignBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.lightclients.solomachine.v1.SignBytes.sequence', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ibc.lightclients.solomachine.v1.SignBytes.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diversifier', full_name='ibc.lightclients.solomachine.v1.SignBytes.diversifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ibc.lightclients.solomachine.v1.SignBytes.data_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"data_type\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ibc.lightclients.solomachine.v1.SignBytes.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1534,
)


_HEADERDATA = _descriptor.Descriptor(
  name='HeaderData',
  full_name='ibc.lightclients.solomachine.v1.HeaderData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_pub_key', full_name='ibc.lightclients.solomachine.v1.HeaderData.new_pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\022yaml:\"new_pub_key\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_diversifier', full_name='ibc.lightclients.solomachine.v1.HeaderData.new_diversifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"new_diversifier\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1537,
  serialized_end=1675,
)


_CLIENTSTATEDATA = _descriptor.Descriptor(
  name='ClientStateData',
  full_name='ibc.lightclients.solomachine.v1.ClientStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ClientStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_state', full_name='ibc.lightclients.solomachine.v1.ClientStateData.client_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"client_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1783,
)


_CONSENSUSSTATEDATA = _descriptor.Descriptor(
  name='ConsensusStateData',
  full_name='ibc.lightclients.solomachine.v1.ConsensusStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ConsensusStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_state', full_name='ibc.lightclients.solomachine.v1.ConsensusStateData.consensus_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"consensus_state\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1785,
  serialized_end=1900,
)


_CONNECTIONSTATEDATA = _descriptor.Descriptor(
  name='ConnectionStateData',
  full_name='ibc.lightclients.solomachine.v1.ConnectionStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ConnectionStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='ibc.lightclients.solomachine.v1.ConnectionStateData.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=2002,
)


_CHANNELSTATEDATA = _descriptor.Descriptor(
  name='ChannelStateData',
  full_name='ibc.lightclients.solomachine.v1.ChannelStateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.ChannelStateData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='ibc.lightclients.solomachine.v1.ChannelStateData.channel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2004,
  serialized_end=2089,
)


_PACKETCOMMITMENTDATA = _descriptor.Descriptor(
  name='PacketCommitmentData',
  full_name='ibc.lightclients.solomachine.v1.PacketCommitmentData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.PacketCommitmentData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='ibc.lightclients.solomachine.v1.PacketCommitmentData.commitment', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2147,
)


_PACKETACKNOWLEDGEMENTDATA = _descriptor.Descriptor(
  name='PacketAcknowledgementData',
  full_name='ibc.lightclients.solomachine.v1.PacketAcknowledgementData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.PacketAcknowledgementData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acknowledgement', full_name='ibc.lightclients.solomachine.v1.PacketAcknowledgementData.acknowledgement', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2149,
  serialized_end=2215,
)


_PACKETRECEIPTABSENCEDATA = _descriptor.Descriptor(
  name='PacketReceiptAbsenceData',
  full_name='ibc.lightclients.solomachine.v1.PacketReceiptAbsenceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.PacketReceiptAbsenceData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2217,
  serialized_end=2257,
)


_NEXTSEQUENCERECVDATA = _descriptor.Descriptor(
  name='NextSequenceRecvData',
  full_name='ibc.lightclients.solomachine.v1.NextSequenceRecvData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ibc.lightclients.solomachine.v1.NextSequenceRecvData.path', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_seq_recv', full_name='ibc.lightclients.solomachine.v1.NextSequenceRecvData.next_seq_recv', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"next_seq_recv\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2344,
)

_CLIENTSTATE.fields_by_name['consensus_state'].message_type = _CONSENSUSSTATE
_CONSENSUSSTATE.fields_by_name['public_key'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_HEADER.fields_by_name['new_public_key'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_MISBEHAVIOUR.fields_by_name['signature_one'].message_type = _SIGNATUREANDDATA
_MISBEHAVIOUR.fields_by_name['signature_two'].message_type = _SIGNATUREANDDATA
_SIGNATUREANDDATA.fields_by_name['data_type'].enum_type = _DATATYPE
_SIGNBYTES.fields_by_name['data_type'].enum_type = _DATATYPE
_HEADERDATA.fields_by_name['new_pub_key'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLIENTSTATEDATA.fields_by_name['client_state'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CONSENSUSSTATEDATA.fields_by_name['consensus_state'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CONNECTIONSTATEDATA.fields_by_name['connection'].message_type = ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2._CONNECTIONEND
_CHANNELSTATEDATA.fields_by_name['channel'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._CHANNEL
DESCRIPTOR.message_types_by_name['ClientState'] = _CLIENTSTATE
DESCRIPTOR.message_types_by_name['ConsensusState'] = _CONSENSUSSTATE
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Misbehaviour'] = _MISBEHAVIOUR
DESCRIPTOR.message_types_by_name['SignatureAndData'] = _SIGNATUREANDDATA
DESCRIPTOR.message_types_by_name['TimestampedSignatureData'] = _TIMESTAMPEDSIGNATUREDATA
DESCRIPTOR.message_types_by_name['SignBytes'] = _SIGNBYTES
DESCRIPTOR.message_types_by_name['HeaderData'] = _HEADERDATA
DESCRIPTOR.message_types_by_name['ClientStateData'] = _CLIENTSTATEDATA
DESCRIPTOR.message_types_by_name['ConsensusStateData'] = _CONSENSUSSTATEDATA
DESCRIPTOR.message_types_by_name['ConnectionStateData'] = _CONNECTIONSTATEDATA
DESCRIPTOR.message_types_by_name['ChannelStateData'] = _CHANNELSTATEDATA
DESCRIPTOR.message_types_by_name['PacketCommitmentData'] = _PACKETCOMMITMENTDATA
DESCRIPTOR.message_types_by_name['PacketAcknowledgementData'] = _PACKETACKNOWLEDGEMENTDATA
DESCRIPTOR.message_types_by_name['PacketReceiptAbsenceData'] = _PACKETRECEIPTABSENCEDATA
DESCRIPTOR.message_types_by_name['NextSequenceRecvData'] = _NEXTSEQUENCERECVDATA
DESCRIPTOR.enum_types_by_name['DataType'] = _DATATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientState = _reflection.GeneratedProtocolMessageType('ClientState', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSTATE,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ClientState)
  })
_sym_db.RegisterMessage(ClientState)

ConsensusState = _reflection.GeneratedProtocolMessageType('ConsensusState', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSSTATE,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ConsensusState)
  })
_sym_db.RegisterMessage(ConsensusState)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.Header)
  })
_sym_db.RegisterMessage(Header)

Misbehaviour = _reflection.GeneratedProtocolMessageType('Misbehaviour', (_message.Message,), {
  'DESCRIPTOR' : _MISBEHAVIOUR,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.Misbehaviour)
  })
_sym_db.RegisterMessage(Misbehaviour)

SignatureAndData = _reflection.GeneratedProtocolMessageType('SignatureAndData', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATUREANDDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.SignatureAndData)
  })
_sym_db.RegisterMessage(SignatureAndData)

TimestampedSignatureData = _reflection.GeneratedProtocolMessageType('TimestampedSignatureData', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPEDSIGNATUREDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.TimestampedSignatureData)
  })
_sym_db.RegisterMessage(TimestampedSignatureData)

SignBytes = _reflection.GeneratedProtocolMessageType('SignBytes', (_message.Message,), {
  'DESCRIPTOR' : _SIGNBYTES,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.SignBytes)
  })
_sym_db.RegisterMessage(SignBytes)

HeaderData = _reflection.GeneratedProtocolMessageType('HeaderData', (_message.Message,), {
  'DESCRIPTOR' : _HEADERDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.HeaderData)
  })
_sym_db.RegisterMessage(HeaderData)

ClientStateData = _reflection.GeneratedProtocolMessageType('ClientStateData', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ClientStateData)
  })
_sym_db.RegisterMessage(ClientStateData)

ConsensusStateData = _reflection.GeneratedProtocolMessageType('ConsensusStateData', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ConsensusStateData)
  })
_sym_db.RegisterMessage(ConsensusStateData)

ConnectionStateData = _reflection.GeneratedProtocolMessageType('ConnectionStateData', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ConnectionStateData)
  })
_sym_db.RegisterMessage(ConnectionStateData)

ChannelStateData = _reflection.GeneratedProtocolMessageType('ChannelStateData', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELSTATEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.ChannelStateData)
  })
_sym_db.RegisterMessage(ChannelStateData)

PacketCommitmentData = _reflection.GeneratedProtocolMessageType('PacketCommitmentData', (_message.Message,), {
  'DESCRIPTOR' : _PACKETCOMMITMENTDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.PacketCommitmentData)
  })
_sym_db.RegisterMessage(PacketCommitmentData)

PacketAcknowledgementData = _reflection.GeneratedProtocolMessageType('PacketAcknowledgementData', (_message.Message,), {
  'DESCRIPTOR' : _PACKETACKNOWLEDGEMENTDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.PacketAcknowledgementData)
  })
_sym_db.RegisterMessage(PacketAcknowledgementData)

PacketReceiptAbsenceData = _reflection.GeneratedProtocolMessageType('PacketReceiptAbsenceData', (_message.Message,), {
  'DESCRIPTOR' : _PACKETRECEIPTABSENCEDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.PacketReceiptAbsenceData)
  })
_sym_db.RegisterMessage(PacketReceiptAbsenceData)

NextSequenceRecvData = _reflection.GeneratedProtocolMessageType('NextSequenceRecvData', (_message.Message,), {
  'DESCRIPTOR' : _NEXTSEQUENCERECVDATA,
  '__module__' : 'ibc.lightclients.solomachine.v1.solomachine_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.solomachine.v1.NextSequenceRecvData)
  })
_sym_db.RegisterMessage(NextSequenceRecvData)


DESCRIPTOR._options = None
_DATATYPE._options = None
_DATATYPE.values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CLIENT_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CONSENSUS_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CONNECTION_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_CHANNEL_STATE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._options = None
_DATATYPE.values_by_name["DATA_TYPE_HEADER"]._options = None
_CLIENTSTATE.fields_by_name['frozen_sequence']._options = None
_CLIENTSTATE.fields_by_name['consensus_state']._options = None
_CLIENTSTATE.fields_by_name['allow_update_after_proposal']._options = None
_CLIENTSTATE._options = None
_CONSENSUSSTATE.fields_by_name['public_key']._options = None
_CONSENSUSSTATE._options = None
_HEADER.fields_by_name['new_public_key']._options = None
_HEADER.fields_by_name['new_diversifier']._options = None
_HEADER._options = None
_MISBEHAVIOUR.fields_by_name['client_id']._options = None
_MISBEHAVIOUR.fields_by_name['signature_one']._options = None
_MISBEHAVIOUR.fields_by_name['signature_two']._options = None
_MISBEHAVIOUR._options = None
_SIGNATUREANDDATA.fields_by_name['data_type']._options = None
_SIGNATUREANDDATA._options = None
_TIMESTAMPEDSIGNATUREDATA.fields_by_name['signature_data']._options = None
_TIMESTAMPEDSIGNATUREDATA._options = None
_SIGNBYTES.fields_by_name['data_type']._options = None
_SIGNBYTES._options = None
_HEADERDATA.fields_by_name['new_pub_key']._options = None
_HEADERDATA.fields_by_name['new_diversifier']._options = None
_HEADERDATA._options = None
_CLIENTSTATEDATA.fields_by_name['client_state']._options = None
_CLIENTSTATEDATA._options = None
_CONSENSUSSTATEDATA.fields_by_name['consensus_state']._options = None
_CONSENSUSSTATEDATA._options = None
_CONNECTIONSTATEDATA._options = None
_CHANNELSTATEDATA._options = None
_NEXTSEQUENCERECVDATA.fields_by_name['next_seq_recv']._options = None
# @@protoc_insertion_point(module_scope)
